==> accounts_management-0.1.6.gem: app/controllers/accounts_management/ledgers/ledger_entry_header_archives_controller.rb <==
require_dependency "accounts_management/accounts_management_controller"

module AccountsManagement
  class Ledgers::LedgerEntryHeaderArchivesController < AccountsManagementController
    # GET /ledgers/ledger_entry_header_archives
    # GET /ledgers/ledger_entry_header_archives.json
    def index
      @ledgers_ledger_entry_header_archives = Ledgers::LedgerEntryHeaderArchive.all

      respond_to do |format|
        format.html # index.html.erb
        format.json { render :json => @ledgers_ledger_entry_header_archives }
      end
    end

    # GET /ledgers/ledger_entry_header_archives/1
    # GET /ledgers/ledger_entry_header_archives/1.json
    def show
      @ledgers_ledger_entry_header_archive = Ledgers::LedgerEntryHeaderArchive.find(params[:id])

      respond_to do |format|
        format.html # show.html.erb
        format.json { render :json => @ledgers_ledger_entry_header_archive }
      end
    end

    # GET /ledgers/ledger_entry_header_archives/new
    # GET /ledgers/ledger_entry_header_archives/new.json
    def new
      @ledgers_ledger_entry_header_archive = Ledgers::LedgerEntryHeaderArchive.new

      respond_to do |format|
        format.html # new.html.erb
        format.json { render :json => @ledgers_ledger_entry_header_archive }
      end
    end

    # GET /ledgers/ledger_entry_header_archives/1/edit
    def edit
      @ledgers_ledger_entry_header_archive = Ledgers::LedgerEntryHeaderArchive.find(params[:id])
    end

    # POST /ledgers/ledger_entry_header_archives
    # POST /ledgers/ledger_entry_header_archives.json
    def create
      @ledgers_ledger_entry_header_archive = Ledgers::LedgerEntryHeaderArchive.new(params[:ledgers_ledger_entry_header_archive])

      respond_to do |format|
        if @ledgers_ledger_entry_header_archive.save
          format.html { redirect_to @ledgers_ledger_entry_header_archive, :notice => 'Ledger entry header archive was successfully created.' }
          format.json { render :json => @ledgers_ledger_entry_header_archive, :status => :created, :location => @ledgers_ledger_entry_header_archive }
        else
          format.html { render :action => "new" }
          format.json { render :json => @ledgers_ledger_entry_header_archive.errors, :status => :unprocessable_entity }
        end
      end
    end

    # PUT /ledgers/ledger_entry_header_archives/1
    # PUT /ledgers/ledger_entry_header_archives/1.json
    def update
      @ledgers_ledger_entry_header_archive = Ledgers::LedgerEntryHeaderArchive.find(params[:id])

      respond_to do |format|
        if @ledgers_ledger_entry_header_archive.update_attributes(params[:ledgers_ledger_entry_header_archive])
          format.html { redirect_to @ledgers_ledger_entry_header_archive, :notice => 'Ledger entry header archive was successfully updated.' }
          format.json { head :no_content }
        else
          format.html { render :action => "edit" }
          format.json { render :json => @ledgers_ledger_entry_header_archive.errors, :status => :unprocessable_entity }
        end
      end
    end

    # DELETE /ledgers/ledger_entry_header_archives/1
    # DELETE /ledgers/ledger_entry_header_archives/1.json
    def destroy
      @ledgers_ledger_entry_header_archive = Ledgers::LedgerEntryHeaderArchive.find(params[:id])
      @ledgers_ledger_entry_header_archive.destroy

      respond_to do |format|
        format.html { redirect_to ledgers_ledger_entry_header_archives_url }
        format.json { head :no_content }
      end
    end
  end
end

==> accounts_management-0.1.7.gem: app/controllers/accounts_management/ledgers/ledger_entry_header_archives_controller.rb <==
require_dependency "accounts_management/accounts_management_controller"

module AccountsManagement
  class Ledgers::LedgerEntryHeaderArchivesController < AccountsManagementController
    # GET /ledgers/ledger_entry_header_archives
    # GET /ledgers/ledger_entry_header_archives.json
    def index
      @ledgers_ledger_entry_header_archives = Ledgers::LedgerEntryHeaderArchive.all

      respond_to do |format|
        format.html # index.html.erb
        format.json { render json: @ledgers_ledger_entry_header_archives }
      end
    end

    # GET /ledgers/ledger_entry_header_archives/1
    # GET /ledgers/ledger_entry_header_archives/1.json
    def show
      @ledgers_ledger_entry_header_archive = Ledgers::LedgerEntryHeaderArchive.find(params[:id])

      respond_to do |format|
        format.html # show.html.erb
        format.json { render json: @ledgers_ledger_entry_header_archive }
      end
    end

    # GET /ledgers/ledger_entry_header_archives/new
    # GET /ledgers/ledger_entry_header_archives/new.json
    def new
      @ledgers_ledger_entry_header_archive = Ledgers::LedgerEntryHeaderArchive.new

      respond_to do |format|
        format.html # new.html.erb
        format.json { render json: @ledgers_ledger_entry_header_archive }
      end
    end

    # GET /ledgers/ledger_entry_header_archives/1/edit
    def edit
      @ledgers_ledger_entry_header_archive = Ledgers::LedgerEntryHeaderArchive.find(params[:id])
    end

    # POST /ledgers/ledger_entry_header_archives
    # POST /ledgers/ledger_entry_header_archives.json
    def create
      @ledgers_ledger_entry_header_archive = Ledgers::LedgerEntryHeaderArchive.new(params[:ledgers_ledger_entry_header_archive])

      respond_to do |format|
        if @ledgers_ledger_entry_header_archive.save
          format.html do
            redirect_to @ledgers_ledger_entry_header_archive, notice: 'Ledger entry header archive was successfully created.'
          end
          format.json do
            render json: @ledgers_ledger_entry_header_archive, status: :created, location: @ledgers_ledger_entry_header_archive
          end
        else
          format.html { render action: "new" }
          format.json { render json: @ledgers_ledger_entry_header_archive.errors, status: :unprocessable_entity }
        end
      end
    end

    # PUT /ledgers/ledger_entry_header_archives/1
    # PUT /ledgers/ledger_entry_header_archives/1.json
    def update
      @ledgers_ledger_entry_header_archive = Ledgers::LedgerEntryHeaderArchive.find(params[:id])

      respond_to do |format|
        if @ledgers_ledger_entry_header_archive.update_attributes(params[:ledgers_ledger_entry_header_archive])
          format.html do
            redirect_to @ledgers_ledger_entry_header_archive, notice: 'Ledger entry header archive was successfully updated.'
          end
          format.json { head :no_content }
        else
          format.html { render action: "edit" }
          format.json { render json: @ledgers_ledger_entry_header_archive.errors, status: :unprocessable_entity }
        end
      end
    end

    # DELETE /ledgers/ledger_entry_header_archives/1
    # DELETE /ledgers/ledger_entry_header_archives/1.json
    def destroy
      @ledgers_ledger_entry_header_archive = Ledgers::LedgerEntryHeaderArchive.find(params[:id])
      @ledgers_ledger_entry_header_archive.destroy

      respond_to do |format|
        format.html { redirect_to ledgers_ledger_entry_header_archives_url }
        format.json { head :no_content }
      end
    end
  end
end
